@@ -26,11 +26,11 @@ from .literals import (
     OrderByType,
 )
 
-if sys.version_info >= (3, 8):
+if sys.version_info >= (3, 9):
     from typing import Literal
 else:
     from typing_extensions import Literal
-if sys.version_info >= (3, 8):
+if sys.version_info >= (3, 9):
     from typing import TypedDict
 else:
     from typing_extensions import TypedDict
@@ -438,7 +438,7 @@ GetProfileResponseTypeDef = TypedDict(
     {
         "contentEncoding": str,
         "contentType": str,
-        "profile": bytes,
+        "profile": StreamingBody,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
